@@ -129,7 +129,7 @@ class NumberFormat(UnicodeMixin, ImmutableMixin):
         # Generate a string that is valid Python input for the constructor.
         # Note that we use rpr (variant of repr), which generates its own quotes.
         result = unicod("NumberFormat(pattern=%s, format=%s") % (rpr(self.pattern), rpr(self.format))
-        if len(self.leading_digits_pattern) > 0:
+        if self.leading_digits_pattern:
             result += (unicod(", leading_digits_pattern=[%s]") %
                        unicod(", ").join([rpr(ld) for ld in self.leading_digits_pattern]))
         if self.national_prefix_formatting_rule is not None:
@@ -178,8 +178,8 @@ class PhoneNumberDesc(UnicodeMixin, ImmutableMixin):
         # number, or to quickly prune numbers that could not possibly be a phone
         # number for this locale.
         if possible_length is None:
-            possible_length = []
-        self.possible_length = possible_length  # list of int
+            possible_length = ()
+        self.possible_length = possible_length  # sequence of int
 
         # These represent the lengths that only local phone numbers (without an area
         # code) from this region can be. They will be sorted from smallest to
@@ -193,8 +193,8 @@ class PhoneNumberDesc(UnicodeMixin, ImmutableMixin):
         # numbers (and the general description) - however there are exceptions for
         # NANPA countries.
         if possible_length_local_only is None:
-            possible_length_local_only = []
-        self.possible_length_local_only = possible_length_local_only  # list of int
+            possible_length_local_only = ()
+        self.possible_length_local_only = possible_length_local_only  # sequence of int
 
     def merge_from(self, other):
         """Merge information from another PhoneNumberDesc object into this one."""
@@ -229,11 +229,11 @@ class PhoneNumberDesc(UnicodeMixin, ImmutableMixin):
         if self.example_number is not None:
             result += unicod("%sexample_number=%s") % (sep, rpr(self.example_number))
             sep = unicod(", ")
-        if len(self.possible_length) > 0:
-            result += unicod("%spossible_length=[%s]") % (sep, ",".join(["%d" % l for l in self.possible_length]))
+        if self.possible_length:
+            result += unicod("%spossible_length=%s") % (sep, tuple(self.possible_length))
             sep = unicod(", ")
-        if len(self.possible_length_local_only) > 0:
-            result += unicod("%spossible_length_local_only=[%s]") % (sep, ",".join(["%d" % l for l in self.possible_length_local_only]))
+        if self.possible_length_local_only:
+            result += unicod("%spossible_length_local_only=%s") % (sep, tuple(self.possible_length_local_only))
             sep = unicod(", ")
         result += unicod(")")
         return result
@@ -244,6 +244,13 @@ class PhoneMetadata(UnicodeMixin, ImmutableMixin):
 
     This class is hand created based on phonemetadata.proto. Please refer to that file
     for detailed descriptions of the meaning of each field.
+
+    WARNING: This API isn't stable. It is considered libphonenumber-internal
+    and can change at any time. We only declare it as public for easy
+    inclusion in our build tools not in this package.  Clients should not
+    refer to this file, we do not commit to support backwards-compatibility or
+    to warn about breaking changes.
+
     """
     # If a region code is a key in this dict, metadata for that region is available.
     # The corresponding value of the map is either:
@@ -605,9 +612,9 @@ class PhoneMetadata(UnicodeMixin, ImmutableMixin):
         if self.national_prefix_transform_rule is not None:
             # Note that we use rpr() on self.national_prefix_transform_rule, which generates its own quotes
             result += unicod(",\n    national_prefix_transform_rule=%s") % rpr(self.national_prefix_transform_rule)
-        if len(self.number_format) > 0:
+        if self.number_format:
             result += unicod(",\n    number_format=[%s]") % unicod(',\n        ').join(map(u, self.number_format))
-        if len(self.intl_number_format) > 0:
+        if self.intl_number_format:
             result += unicod(",\n    intl_number_format=[%s]") % unicod(',\n        ').join(map(u, self.intl_number_format))
         if self.main_country_for_code:
             result += unicod(",\n    main_country_for_code=True")
